# PyGT : Numerically stable analysis of metastable Markov chains in Python

> Tom Swinburne, CNRS-CINaM, swinburne at cinam.univ-mrs.fr

> Deepti Kannan, U Cambridge

v0.1.0 :copyright: TD Swinburne and D Kannan 2020

Beta version of code used in the papers below. Please see full documentation and examples at [readthedocs](https://pygt.readthedocs.io)

T.D. Swinburne and D.J. Wales, *Defining, Calculating, and Converging Observables of a Kinetic Transition Network*, J. Chemical Theory and Computation (2020), [link](https://doi.org/10.1021/acs.jctc.9b01211)

T.D. Swinburne, D. Kannan, D.J. Sharpe and D.J. Wales, *Rare Events and First Passage Time Statistics From the Energy Landscape*,
J. Chemical Physics (accepted 2020)
